function [DAMACY_output, X,C_scores] = DAMACY_top_fusion(C,Labels, pc_used, DAMACY_settings)
%%


%%
if ~isempty(DAMACY_settings)
binsize = DAMACY_settings.binsize; 
else
    binsize = [500 500]; 
end

if isfield(C{1}(1), 'train')
    trainset = logical(vertcat(C{1}.train));
else
    trainset = true(length(C{1}),1);
end

%%
N_PCs = length(pc_used);
X = cellfun(@blockscale_struct, C, 'uniformoutput', false); 
[~, LDS] = cellfun(@pcafunction, X, 'uniformoutput', false); 

%% Project data
% Time 0.3
number_samples = length(C{1}); 
number_sets = length(C); 
C_scores = C;
for l1 = 1:number_sets
    for l2 = 1:number_samples
        C_scores{l1}(l2).Data = C{l1}(l2).Data*LDS{l1}(:,pc_used{l1});
    end
end

X = cellfun(@(a) vertcat(a(trainset).Data),C_scores, 'uniformoutput', false);
edges = cellfun(@(a) binedges(a, [binsize], 0.01, 1), X, 'uniformoutput', false); 

%% Create Histograms
% Time: 90 seconds

X = [];
Histograms = zeros([number_samples binsize]);
for l2 = 1:number_sets
    for l1 = 1:number_samples
        Histograms(l1,:,:,:,:,:,:) = NDhist(C_scores{l2}(l1).Data, edges{l2}, 5);
    end
    X = [X reshape(Histograms,number_samples, prod(binsize))]; 
end

%% remove empty bins (DAMACY)
%Note: Empty bins should not be taken into account to circumvent seperation
%based on empty vs not empty. The empty bins are not 0, but have a very low
%value due to the smoothing.
ind = std(X) > 10^-6;
% X1 = X1/sqrt(sum(X1(:).^2));
% X2 = X2/sqrt(sum(X2(:).^2));
% X = [X1 X2];
X = X(:,ind);

%% create class vector Y and train and test set (DAMACY)
%Time: 0 seconds

Y2 = Labels == 0;
Y1 = ~Y2;
Y = Y1 - Y2;

%% OPLS (DAMACY)

[b_acc, n_LV] = Damacy_top_cv_acc_lvonly(X(trainset,:), Y(trainset), 20);

mean_Y = mean(Y(trainset));
mean_X = mean(X(trainset,:));
Y_train = (Y(trainset) - repmat(mean_Y,size(Y(trainset),1),1));%./(repmat(std_Y, size(Ytrain,1),1));
X_train = (X(trainset,:) - repmat(mean_X, size(X(trainset,:),1),1));%./(repmat(std_X, size(Xtrain,1),1));
X_test = (X(~trainset,:) - repmat(mean_X, size(X(~trainset,:),1),1));%./(repmat(std_X, size(Xtest,1),1));
[w,t,p,    q,T_o,P_o,W_o] = OPLS(X_train,Y_train,n_LV); %2 class
% VIP=vip(X,t,w,q);
% ind2 = VIP > 1;
% X_train = X_train(:,ind2);
% X_test = X_test(:,ind2);
% [w,~,~,    q,~,P_o,W_o] = OPLS(X_train,Y_train,n_LV); %2 class
[tnew,tnew_o,yhat] = OPLSpred(X_test,P_o,W_o,w,q,n_LV); %2 class

Y_pred1 = yhat >  - mean_Y;
Y_pred2 = yhat <  - mean_Y;
Y_pred = Y_pred1 - Y_pred2;
Y_test = Y(~trainset);
accf = sum(Y_pred == Y_test)/length(Y_test);
DAMACY_output.spec = sum(Y_pred((Y_test == -1)) == Y_test(Y_test == -1))/length(Y_test(Y_test == -1));
DAMACY_output.sens = sum(Y_pred((Y_test == 1)) == Y_test(Y_test == 1))/length(Y_test(Y_test == 1));
DAMACY_output.accuracy = accf;
DAMACY_output.base_accuracy = b_acc;

%% DAMACY output
DAMACY_output.LDS = LDS;
DAMACY_output.edges = edges;
DAMACY_output.indices = ind;
DAMACY_output.weights = w;
DAMACY_output.yhat = yhat;
DAMACY_output.OPLS_model.n_LV = n_LV;
DAMACY_output.OPLS_model.q = q;
total_t = zeros(size(Y));
total_t(trainset) = t; 
total_t(~trainset) = tnew; 
DAMACY_output.OPLS_model.t = total_t;
DAMACY_output.OPLS_model.p = p;
DAMACY_output.OPLS_model.P_o = P_o;
total_to = zeros(size(Y,1), n_LV);
total_to(trainset,:) = T_o; 
total_to(~trainset,:) = tnew_o; 
DAMACY_output.OPLS_model.T_o = total_to;
DAMACY_output.OPLS_model.W_o = W_o;
DAMACY_output.binsize = binsize; 





