function plot_DAMACY_2dmap_top_fusion(DAMACY_output, Labels, ID,V, pc_used)
%%
% Function to plot the DAMACY map
% Works only for 2D maps!
%
% Input: 
% w         weights of the OPLS-DA model
% binsize   contains the number of bins per PC
% ind       indices containing which bins are selected for OPLS-DA
% Y         Y dummy vector containing -1 for control +1 for diseased
% mean_Y    Mean of Y vector
% yhat      yhat calculated by the OPLS-DA model
% ID        containing the patient ID (used to plot the patient ID next to
%           the diagnostic score, if left empty the text will not be plotted)
% edges     number of PCs by number of bins per PC, containing the boundaries of each bins in the PC space
% VAR       The Variance explained per PC
% LDS       The Loadings of PCA model
% pc_used   Contains the two pc used as vector, e.g. [1 2] for the first
% two PCs
% control   string containing the title of the control group
% challenged string containing tht title of the challenged group
% marker_names cell containing the names of each variable
% 
% Written by G.H. Tinnevelt and M. Kokla on 21-5-2015 at Raboud University
% Edited by G.H. Tinnevelt on 22-5-2015 at Radboud University; added mean_Y
% and PC used as input
% Edited by G.H. Tinnevelt on 21-6-2015 at Radboud University; input is now
% DAMACY_output struct
%
%%
nbins = size(DAMACY_output.indices,2); 
n_sets = length(V); 
W = zeros(nbins,1); 
W(DAMACY_output.indices) = DAMACY_output.weights; 
non_zero_weights = DAMACY_output.weights(DAMACY_output.weights ~= 0);
weight_minmax_value = (prctile(non_zero_weights,99) - prctile(non_zero_weights,1))/2;
c = 0; 
x = cell(n_sets, 1); 
for l1 = 1:n_sets
    d = c+nbins/n_sets; 
    x{l1} = reshape(W(1+c:d), DAMACY_output.binsize);
    c = d; 
end

Y2 = Labels == 0;
Y1 = ~Y2;
Y = Y1 - Y2;
mean_Y = mean(Y);
plot_width = n_sets*2 + 1; 

load('cmap_bluered.mat')
idx1 = Y == -1;
idx2 = Y == 1;
yhat2 = DAMACY_output.yhat + mean_Y;

figure
subplot(2, plot_width ,[1 plot_width+1]);hold on
plot(zeros(sum(Y==-1),1),yhat2(idx1),'ro','markerfacecolor','r', 'markersize', 24)
plot(zeros(sum(Y==1),1),yhat2(idx2), 'bx','markerfacecolor','b', 'linewidth', 3, 'markersize', 24)
text(0.1*ones(length(yhat2),1), yhat2, num2cell(ID))

set(gca, 'Xtick', [])
set(gca, 'Ytick', [-1 0 1])
set(gca, 'YtickLabel', {'Control', 'Threshold', 'Case'})
set(gca, 'fontsize', 20)
% legend({control,challenged},'FontSize',8,'FontWeight','bold')
drawaxis(gca, 'x', 0, 'movelabel', 1)
ax = gca; 
ax.XColor = 'white';
% title('Prediction scores', 'fontsize', 22)

for l1 = 1:n_sets
subplot(2, plot_width ,[2*l1 1+plot_width + 2*l1]);
colormap(cmap)
imagesc(DAMACY_output.edges{l1}(1,:), DAMACY_output.edges{l1}(2,:), x{l1}', [-weight_minmax_value weight_minmax_value])
hold on
DA_FLplotloadings(DAMACY_output.LDS{l1}(:,pc_used{l1}), V{l1})
hold off
set(gca, 'Xtick', [])
set(gca, 'Ytick', [])
axis('square')
% title('Cell Map ~ OPLSDA weights', 'fontsize', 22)
set(gca, 'YDir', 'normal');

end


end