function [Gating_table, S_gated, err_Y] = gate_data_DAMACY(S, VariableNames, S_scores, Histograms, DAMACY_output, varargin)

%%
Labels = vertcat(S.Labels);
Y = Labels - ~Labels;

%%
% plot figure
x = zeros([DAMACY_output.binsize]);
x(DAMACY_output.indices) = DAMACY_output.weights;
edges = DAMACY_output.edges;
binsize = repmat(size(edges,2),1, size(edges,1));
figure
imagesc(edges(1,:),edges(2,:), x', [- 0.016 0.016])
set(gca, 'Xtick', [])
set(gca, 'Ytick', [])
title('Cell Map ~ PLSDA regression coefficients', 'fontsize', 22)
set(gca, 'YDir', 'normal');
load('cmap_bluered.mat')
colormap(cmap)
hold on

% set masks
% a = x > 0.0005; %over expression
% b = x < -0.0005; %under expression
% cc_a = bwconncomp(a, 4); %segment image
% cc_b = bwconncomp(b, 4); %segment image
if ~isempty(varargin)
    [cc_a, cc_b] = segment_gates(x, varargin(6));
else
    [cc_a, cc_b] = segment_gates(x, binsize);
end

%create table
S_gated = S;
data = vertcat(S.Data); %data matrix
% min_value = prctile(vertcat(S.Data),0.1); 
% data = data - repmat(min_value, size(data,1), 1) +1;
% data(data < 1) = 1; %remove negative values
% data = log10(data); %perform log transformation for better visualization
% 
% data = vertcat(S.Data);
% cofactor = abs(prctile(data(data<0),1));
% data = flow_arcsinh(data, cofactor);
Gating_table = cell(0);
Gating_table(1,1) = {'Region\marker'};
Gating_table(1,2) = {'Patient_cellfreq'};
Gating_table(1,3) = {'Control_cellfreq'};
Gating_table(1,4:length(VariableNames)+3) = VariableNames;
colors = {'y', 'm', 'c', 'g','k','r', 'b'};


%create data matrices
Data = vertcat(S_scores.Data);
BinArray = zeros(size(Data, 1), size(edges, 1)); % preallocate, each sample gets Ndim coordinates
for l1 = 1:size(edges,1)
    [~, BinArray(:, l1)] = histc(Data(:, l1), edges(l1, :)); %position of cells in histogram
end

%loop counters
cell_list = [];
count = 1;

% select cells of over expression
for l1 = 1:size(cc_a.PixelIdxList,2)
    cell_cluster = cc_a.PixelIdxList{l1};
    if length(cell_cluster) > 24
        CH = zeros(DAMACY_output.binsize);
        CH(cell_cluster) = 1;
        color_input = colors{rem(count-1,7)+1};
        plot_CI_hull(CH, edges, color_input);
        count = count + 1;
        Gate_name = ['Case' num2str(count-1) color_input];
        Gate_name_percentage = [Gate_name 'percentage'];
        Gate_names_percentages(count-1) = {Gate_name_percentage};
        Gating_table(count, 1) = {Gate_name};
        h = 1:prod(DAMACY_output.binsize);
        [h2(:,1), h2(:,2)] = ind2sub(binsize, h);
        h3 = h2(cell_cluster,:);
        Region1 = ismember(BinArray, h3, 'rows');
        data_selected = median((data(Region1,:)));
        Gating_table(count,4:length(VariableNames)+3) = num2cell(data_selected);
        err_Y(count-1,:,1) = data_selected - prctile((data(Region1,:)),25);
        err_Y(count-1,:,2) = prctile((data(Region1,:)),75) - data_selected;
        Patient_cellfreq =  squeeze(mean(Histograms(Y == 1,cell_cluster)));
        Patient_cellfreq = sum(Patient_cellfreq(:))*100;
        Gating_table(count, 2) = num2cell(Patient_cellfreq);
        Control_cellfreq = squeeze(mean(Histograms(Y == -1,cell_cluster)));
        Control_cellfreq = sum(Control_cellfreq(:))*100;
        Gating_table(count, 3) = num2cell(Control_cellfreq);
        cell_list = [cell_list; cell_cluster];
        for l2 = 1:length(S_gated)
            data_tmp = S_scores(l2).Data;
            BinArray_tmp = zeros(size(data_tmp, 1), size(edges, 1)); % preallocate, each sample gets Ndim coordinates
            for l3 = 1:size(edges,1)
                [~, BinArray_tmp(:, l3)] = histc(data_tmp(:, l3), edges(l3, :)); %position of cells in histogram
            end
            region_tmp = ismember(BinArray_tmp, h3, 'rows');
            S_gated(l2).(Gate_name) = S(l2).Data(region_tmp,:);
            S_gated(l2).(Gate_name_percentage) = size(S_gated(l2).(Gate_name),1)/size(S(l2).Data,1)*100;
        end
    end
end
control_number = size(Gating_table,1);
%select cells of under expression
for l1 = 1:size(cc_b.PixelIdxList,2)
    cell_cluster = cc_b.PixelIdxList{l1};
    if length(cell_cluster) > 24
        CH = zeros(DAMACY_output.binsize);
        CH(cell_cluster) = 1;
        color_input = colors{rem(count-1,7)+1};
        plot_CI_hull(CH, edges, color_input);
        count = count + 1;
        Gate_name = ['Control' num2str(count-control_number) color_input];
        Gate_name_percentage = [Gate_name 'percentage'];
        Gate_names_percentages(count-1) = {Gate_name_percentage};
        Gating_table(count, 1) = {Gate_name};
        h = 1:prod(DAMACY_output.binsize);
        [h2(:,1), h2(:,2)] = ind2sub(binsize, h);
        h3 = h2(cell_cluster,:);
        Region1 = ismember(BinArray, h3, 'rows');
        data_selected = median((data(Region1,:)));
        Gating_table(count,4:length(VariableNames)+3) = num2cell(data_selected);
        err_Y(count-1,:,1) = data_selected - prctile((data(Region1,:)),25);
        err_Y(count-1,:,2) = prctile((data(Region1,:)),75) - data_selected;
        Patient_cellfreq =  squeeze(mean(Histograms(Y == 1,cell_cluster)));
        Patient_cellfreq = sum(Patient_cellfreq(:))*100;
        Gating_table(count, 2) = num2cell(Patient_cellfreq);
        Control_cellfreq = squeeze(mean(Histograms(Y == -1,cell_cluster)));
        Control_cellfreq = sum(Control_cellfreq(:))*100;
        Gating_table(count, 3) = num2cell(Control_cellfreq);
        cell_list = [cell_list; cell_cluster];
        for l2 = 1:length(S_gated)
            data_tmp = S_scores(l2).Data;
            BinArray_tmp = zeros(size(data_tmp, 1), size(edges, 1)); % preallocate, each sample gets Ndim coordinates
            for l3 = 1:size(edges,1)
                [~, BinArray_tmp(:, l3)] = histc(data_tmp(:, l3), edges(l3, :)); %position of cells in histogram
            end
            region_tmp = ismember(BinArray_tmp, h3, 'rows');
            S_gated(l2).(Gate_name) = S(l2).Data(region_tmp,:);
            S_gated(l2).(Gate_name_percentage) = size(S_gated(l2).(Gate_name),1)/size(S(l2).Data,1)*100;
        end
    end
end

%select cells not taken
h = 1:prod(DAMACY_output.binsize);
cell_cluster = setdiff(h, cell_list);
count = count + 1;
Gating_table(count, 1) = {'Cells not included'};
[h2(:,1), h2(:,2)] = ind2sub(binsize, h);
h3 = h2(cell_cluster,:);
Region1 = ismember(BinArray, h3, 'rows');

data_selected = median((data(Region1,:)));
Gating_table(count,4:length(VariableNames)+3) = num2cell(data_selected);
Patient_cellfreq =  squeeze(mean(Histograms(Y == 1,cell_cluster)));
Patient_cellfreq = sum(Patient_cellfreq(:))*100;
Gating_table(count, 2) = num2cell(Patient_cellfreq);
Control_cellfreq = squeeze(mean(Histograms(Y == -1,cell_cluster)));
Control_cellfreq = sum(Control_cellfreq(:))*100;
Gating_table(count, 3) = num2cell(Control_cellfreq);
for l2 = 1:length(S_gated)
    data_tmp = S_scores(l2).Data;
    BinArray_tmp = zeros(size(data_tmp, 1), size(edges, 1)); % preallocate, each sample gets Ndim coordinates
    for l3 = 1:size(edges,1)
        [~, BinArray_tmp(:, l3)] = histc(data_tmp(:, l3), edges(l3, :)); %position of cells in histogram
    end
    region_tmp = ismember(BinArray_tmp, h3, 'rows');
    S_gated(l2).Cells_not_included = S(l2).Data(region_tmp,:);
    S_gated(l2).percentage_outside = size(S_gated(l2).Cells_not_included,1)/size(S(l2).Data,1)*100;
end
Gate_names_percentages(count-1) = {'percentage_outside'};
% plot loadings
% DA_FLplotloadings(DAMACY_output.PCAloading(:,DAMACY_output.pc_used), VariableNames)
y = [];
for l1 = 1:length(Gate_names_percentages)
    y = [y vertcat(S_gated.(Gate_names_percentages{l1}))];
end
figure
bp = bar(y, 'stacked'); %barplot
Labels = vertcat(S.Labels); % 0 is control, 1 is diseased
ID = {S.ID};
set(gca, 'Xtick', [])
ax2 = copyobj(gca, gcf);
set(ax2, 'Xtick', find(Labels == 0), 'XtickLabel', ID(Labels == 0), 'XColor', 'r')
ax3 = copyobj(gca, gcf);
set(ax3, 'Xtick', find(Labels == 1), 'XtickLabel', ID(Labels == 1), 'XColor', 'b')
Gating_X = cell2mat(Gating_table(2:end-1, 4:end)');
figure
err_Y = permute(err_Y, [2 1 3]);
bpe = barwitherr(err_Y, Gating_X);
set(gca, 'XtickLabel', VariableNames, 'Ytick', [])
set(gca, 'fontsize', 20)
bp = flipud(allchild(ax3));
for l1 = 1:size(Gating_X, 2)
    set(bpe(l1), 'FaceColor',  colors{rem(l1-1,7)+1})
    set(bp(l1), 'FaceColor', colors{rem(l1-1,7)+1})
end
set(bp(end), 'FaceColor', [0.5 0.1 0.1])