 function plot_2d_histograms(Histogram, edges, VAR, pc_used)
%%
% Plots a histogram and PCA loadings on top and gives a title and x and y label. 
% Input:
% Histogram:        The histogram you want to plot
% edges:            A 2xbinsize matrix with the binedges
% LDS:              Loadings of PCA
% VAR:              Variance of PCA
% VariableNames:    The VariableNames of the Loadings
% pc_used:          The PCs used in the PCA model
%
% Output:
% No output but a figure will appear
%
% For example:
% plot_2d_histograms(squeeze(Histogram(x,:,:)), edges, LDS, VAR, VariableNames(var_used))
%
%
% Written by G.H. Tinnevelt on 20-2-2015 at the Radboud University Nijmegen
% Edited by G.H. Tinnevelt on 22-4-2015, able to use different PCs
%%
imagesc(edges(1,:),edges(2,:),Histogram', [0 3e-4])
set(gca, 'YDir', 'normal', 'Xtick', [], 'Ytick', [], 'fontsize', 23);
xlabel(['PC' num2str(pc_used(1)) ' (' num2str(VAR(1)) '%)'], 'fontsize', 23)
ylabel(['PC' num2str(pc_used(2)) ' (' num2str(VAR(2)) '%)'], 'fontsize', 23)
colorbar
