function plot_DAMACY_2dmap(DAMACY_output, Labels, ID, control, challenged)
%%
% Function to plot the DAMACY map
% Works only for 2D maps!
%
% Input: 
% w         weights of the OPLS-DA model
% binsize   contains the number of bins per PC
% ind       indices containing which bins are selected for OPLS-DA
% Y         Y dummy vector containing -1 for control +1 for diseased
% mean_Y    Mean of Y vector
% yhat      yhat calculated by the OPLS-DA model
% ID        containing the patient ID (used to plot the patient ID next to
%           the diagnostic score, if left empty the text will not be plotted)
% edges     number of PCs by number of bins per PC, containing the boundaries of each bins in the PC space
% VAR       The Variance explained per PC
% LDS       The Loadings of PCA model
% pc_used   Contains the two pc used as vector, e.g. [1 2] for the first
% two PCs
% control   string containing the title of the control group
% challenged string containing tht title of the challenged group
% marker_names cell containing the names of each variable
% 
% Written by G.H. Tinnevelt and M. Kokla on 21-5-2015 at Raboud University
% Edited by G.H. Tinnevelt on 22-5-2015 at Radboud University; added mean_Y
% and PC used as input
% Edited by G.H. Tinnevelt on 21-6-2015 at Radboud University; input is now
% DAMACY_output struct
%
%%
ind = DAMACY_output.indices; 
w = DAMACY_output.weights; 
yhat = DAMACY_output.yhat; 
edges = DAMACY_output.edges;
binsize = repmat(size(edges,2), 1, size(edges,1));
VAR = DAMACY_output.PCAvariance; 
pc_used = DAMACY_output.pc_used;
Y2 = Labels == 0;
Y1 = ~Y2;
Y = Y1 - Y2;
mean_Y = mean(Y);

%%
load('cmap_bluered.mat')
x = zeros(binsize);
x(ind) = w;
idx1 = Y == -1;
idx2 = Y == 1;
yhat2 = yhat + mean_Y;

figure
subplot(2, 3 ,[1 4]);hold on
plot(zeros(sum(Y==-1),1),yhat2(idx1),'ro','markerfacecolor','r', 'markersize', 18)
plot(zeros(sum(Y==1),1),yhat2(idx2), 'bx','markerfacecolor','b', 'markersize', 18, 'linewidth', 3)
% text(0.1*ones(length(yhat2),1), yhat2, num2cell(ID))
set(gca, 'Xtick', [])
set(gca, 'Ytick', [-1 0 1])
set(gca, 'YtickLabel', {'Control', 'Threshold', 'Challenged'})
set(gca, 'fontsize', 23)
% legend({control,challenged},'FontSize',22,'FontWeight','bold')
drawaxis(gca, 'x', 0, 'movelabel', 1)
ax = gca; 
ax.XColor = 'white';
% title('Prediction scores', 'fontsize', 22)

subplot(2, 3 ,[2,6]);
colormap(cmap)
imagesc(edges(1,:),edges(2,:), x', [- 0.016 0.016])
set(gca, 'Xtick', [])
set(gca, 'Ytick', [])

% title('Cell Map ~ OPLSDA weights', 'fontsize', 22)
set(gca, 'YDir', 'normal');
xlabel(['PC' num2str(pc_used(1)) ' (' num2str(VAR(pc_used(1))) '%)'], 'fontsize', 23)
ylabel(['PC' num2str(pc_used(2)) ' (' num2str(VAR(pc_used(2))) '%)'], 'fontsize', 23)


end