function plot_biplot(SCR, LDS, VAR, VariableNames, pc_used,edges, Labels)
%%
% Plot a biplot and gives a title and x and y label.
% Input:
% SCR:              Scores of PCA
% LDS:              Loadings of PCA
% VAR:              Variance of PCA
% pc_used
% VariableNames:    The VariableNames of the Loadings
%
% Output:
% No output but a figure will appear
%
% For example:
% plot_biplot(SCR, LDS, VAR, VariableNames, pc_used, edges, Labels)
%
%
% Written by G.H. Tinnevelt on 20-2-2015 at the Radboud University Nijmegen
% Edited by G.H. Tinnevelt on 22-4-2015, able to use different PCs
%%
if isempty(Labels)
    plot(SCR(:,pc_used(1)), SCR(:,pc_used(2)), '.');
else
    plot(SCR(Labels == 0,pc_used(1)), SCR(Labels == 0,pc_used(2)), 'ro', 'markersize', 24, 'markerfacecolor', 'r');
    hold on
    plot(SCR(Labels == 1,pc_used(1)), SCR(Labels == 1,pc_used(2)), 'bx', 'markersize', 24, 'linewidth', 5);
end
if ~isempty(edges)
    axis([edges(1,1) edges(1,end) edges(2,1) edges(2,end)]);
end
if ~isempty(VariableNames)
    hold on
    DA_FLplotloadings(LDS(:,pc_used), VariableNames)
end
set(gca, 'YDir', 'normal');
xlabel(['PC' num2str(pc_used(1)) ' (' num2str(VAR(pc_used(1))) '%)'], 'fontsize', 24)
ylabel(['PC' num2str(pc_used(2)) ' (' num2str(VAR(pc_used(2))) '%)'], 'fontsize', 24)
set(gca, 'Xtick', [], 'Ytick', [])
end