function plot_histogram_with_hull(Histograms, paired_data, DAMACY_output, VariableNames, Labels, ID)
%%
% Plots 2D histograms with confidence border based on histograms. If the
% data is paired, the border will be based on each individuals own
% measurement.  If the data is unpaired the border is based on all
% individuals. The healthy/control border (Labels == 0) is plotted in
% cyan and the diseased/challenged border (Labels == 1) is plotted in red.
%
% Written by G.H. Tinnevelt
%%
ind_VAR  = DAMACY_output.ind_PCAvariance;
pc_used = DAMACY_output.pc_used;
load('cmap_histogram.mat')
CI_value = input('What confidence interval do you want to use? (in percentages): ');
str=input('Do you want to save the figures? [y or n] ','s');
if paired_data == 1
    ff = unique(ID);
    for l1 = 1:length(ff)
        tmp_id = find(ID == ff(l1));
        tmp_healthy_id = Labels == 0;
        tmp_healthy_id = tmp_id(tmp_healthy_id(tmp_id));
        tmp_diseased_id = Labels == 1;
        tmp_diseased_id = tmp_id(tmp_diseased_id(tmp_id));
        CH_healthy = con_hul2(permute(Histograms(tmp_healthy_id,:,:), [2 3 1]), CI_value);
        CH_diseased = con_hul2(permute(Histograms(tmp_diseased_id,:,:), [2 3 1]), CI_value);
        for l2 = 1:length(tmp_id)
            figure
            plot_2d_histograms(squeeze(Histograms(tmp_id(l2),:,:)), DAMACY_output.edges, DAMACY_output.PCAloading, ind_VAR(tmp_id(l2),:), VariableNames, DAMACY_output.pc_used)
            colormap(cmap)
            colorbar
            title({['Histogram of class ' num2str(Labels(tmp_id(l2)))] ['Individual: ' num2str(ID(tmp_id(l2))) ]}, 'fontsize', 22)
            hold on
            plot_CI_hull(CH_healthy, DAMACY_output.edges, [0 1 1]);
            plot_CI_hull(CH_diseased, DAMACY_output.edges, [1 0 0 ]);
            DA_FLplotloadings(DAMACY_output.PCAloading(:,pc_used), VariableNames)
            %              export_fig(sprintf('Histograms of individual %d of class %d in response space', ID(tmp_id(l2)), Labels(tmp_id(l2))), '-png')
        end
    end
else
    CH_healthy = con_hul2(permute(Histograms(Labels == 0,:,:), [2 3 1]), CI_value);
    CH_diseased = con_hul2(permute(Histograms(Labels == 1,:,:), [2 3 1]), CI_value);
    for l1 = 1:size(Histograms,1)
        figure
        plot_2d_histograms(squeeze(Histograms(l1,:,:)),  DAMACY_output.edges, DAMACY_output.PCAloading, ind_VAR(l1,:), VariableNames, DAMACY_output.pc_used)
        colormap(chistogrammap)
        title({['Histogram of class ' num2str(Labels(l1))] ['Individual: ' num2str(ID(l1)) ]}, 'fontsize', 22)
        hold on
        plot_CI_hull(CH_healthy, DAMACY_output.edges, [0 1 1]);
        plot_CI_hull(CH_diseased, DAMACY_output.edges, [1 0 0 ]);
        DA_FLplotloadings(DAMACY_output.PCAloading(:,pc_used), VariableNames)
        if strcmp(str,'y')==1
            if Labels(l1) == 0
                Labeltext = 'control ';
            else
                Labeltext = 'asthma patient ';
            end
            % save Figures
            temp=['Histogram of ' Labeltext num2str(ID(l1)),'.png'];
            saveas(gca,temp);
            temp2=['Histogram of ' Labeltext num2str(ID(l1)),'.fig'];
            saveas(gca,temp2);
        end
    end
end
end

